import { Injectable, Logger, NotFoundException } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { EntityNotFoundError, Repository } from 'typeorm';
import { Staff } from './entities/staff.entity';
import { StaffCreateDto } from './dto/staff-create.dto';
import { StaffUpdateDto } from './dto/staff-update.dto';

@Injectable()
export class StaffsService {
  constructor(
    private readonly logger: Logger,
    @InjectRepository(Staff)
    private staffsRepository: Repository<Staff>,
  ) {}

  create(staffCreateDto: StaffCreateDto): Promise<Staff> {
    // Use Repository.create() will copy the values to destination object.
    const staff = this.staffsRepository.create(staffCreateDto);
    return this.staffsRepository.save(staff);
  }

  findAll(): Promise<Staff[]> {
    return this.staffsRepository.find();
  }

  findOne(id: number): Promise<Staff> {
    return this.staffsRepository.findOneOrFail({ where: { id } });
  }

  async update(id: number, staffUpdateDto: StaffUpdateDto): Promise<void> {
    await this.isExist(id);
    await this.staffsRepository.update({ id }, staffUpdateDto);
  }

  async remove(id: number): Promise<void> {
    await this.isExist(id);
    await this.staffsRepository.delete(id);
  }

  // Helper function: Check if the entity exist.
  // If entity does not exsit, return the Promise.reject()
  private async isExist(id: number): Promise<void> {
    const cnt = await this.staffsRepository.countBy({ id });
    if (cnt > 0) {
      return;
    } else {
      return Promise.reject(new EntityNotFoundError(Staff, { where: { id } }));
    }
  }
}
